<?xml version="1.0" encoding="ISO-8859-1" standalone="yes"?>
<!--
The Apache Software License, Version 1.1

Copyright (c) 1999, 2000 The Apache Software Foundation.  All rights
reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in
   the documentation and/or other materials provided with the
   distribution.

3. The end-user documentation included with the redistribution, if
   any, must include the following acknowlegement:
      "This product includes software developed by the
       Apache Software Foundation (http://www.apache.org/)."
   Alternately, this acknowlegement may appear in the software itself,
   if and wherever such third-party acknowlegements normally appear.

4. The names "The Jakarta Project", "Ant", and "Apache Software
   Foundation" must not be used to endorse or promote products derived
   from this software without prior written permission. For written
   permission, please contact apache@apache.org.

5. Products derived from this software may not be called "Apache"
   nor may "Apache" appear in their names without prior written
   permission of the Apache Group.

THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
====================================================================

This software consists of voluntary contributions made by many
individuals on behalf of the Apache Software Foundation.  For more
information on the Apache Software Foundation, please see
<http://www.apache.org/>.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xrn="http://xmlreleasenotes.free.fr" xmlns:xrna="http://xmlreleasenotes.free.fr/Actors" exclude-result-prefixes="xrn xrna">
	<!--
	This file belongs to XMLReleaseNotes V0.18.0.
	-->
	<!--
	This is the common XSLT that contains all the parameters and helper named templates.
	-->
	<xsl:import href="XMLReleaseNotesCommon.xsl"/>
	<xsl:output indent="yes" method="xml" encoding="ISO-8859-1" doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN" doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>
	<xsl:template match="xrn:ReleaseNotes">
		<xsl:call-template name="_checkVersion"/>
		<xsl:choose>
			<xsl:when test="$standAloneHTML = 'true'">
				<html>
					<xsl:call-template name="_printHead">
						<xsl:with-param name="title">Release Notes of <xsl:value-of select="@ID"/>
						</xsl:with-param>
					</xsl:call-template>
					<body>
						<xsl:call-template name="_printSingle"/>
					</body>
				</html>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_printSingle"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the body content of the release notes, when a single page is being asked for.
	-->
	<xsl:template name="_printSingle">
		<div class="releaseNotes">
			<table class="releases" cellspacing="0" cellpadding="10" width="100%">
				<thead>
					<tr>
						<td>
							<xsl:choose>
								<xsl:when test="$abstract">
									<p>
										<xsl:value-of select="$abstract" disable-output-escaping="yes"/>
									</p>
								</xsl:when>
								<xsl:otherwise>
									<xsl:text>The following table shows the history of </xsl:text>
									<b>
										<xsl:value-of select="@ID"/>
									</b>
									<xsl:text> release notes.</xsl:text>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</thead>
				<tbody>
					<xsl:apply-templates select="Releases"/>
				</tbody>
				<xsl:if test="$banner">
					<tfoot>
						<tr>
							<td class="copyrightXRNInternal">
								<xsl:call-template name="_printBottomBanner"/>
							</td>
						</tr>
					</tfoot>
				</xsl:if>
			</table>
			<br/>
		</div>
	</xsl:template>
	<!--
	Prints the HTML 'head' tag for every generated HTML page.
	Take a look at the parameters.
	-->
	<xsl:template name="_printHead">
		<xsl:param name="title"/>
		<head>
			<title>
				<xsl:value-of select="$title"/>
			</title>
			<xsl:call-template name="_printMetaAndLink"/>
		</head>
	</xsl:template>
	<!--
	Prints the HTML 'meta' and 'link' part of the 'head' tag for every generated HTML page.
	-->
	<xsl:template name="_printMetaAndLink">
		<xsl:call-template name="_printMeta"/>
		<xsl:if test="$CSS != ''">
			<link rel="StyleSheet" type="text/css" media="all">
				<xsl:attribute name="href"><xsl:value-of select="$CSS"/></xsl:attribute>
			</link>
		</xsl:if>
		<xsl:if test="$CSSContent != ''">
			<style type="text/css" media="all">
				<xsl:copy-of select="$CSSContent"/>
			</style>
		</xsl:if>
	</xsl:template>
	<!--
	Prints only the HTML 'meta' part of the 'head' tag for every generated HTML page.
	-->
	<xsl:template name="_printMeta">
		<meta name="Author" content="XMLReleaseNotes"/>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes/Releases">
		<xsl:for-each select="Release">
			<tr>
				<xsl:attribute name="class"><xsl:choose><xsl:when test="(position() mod 2) = 0">releaseEven</xsl:when><xsl:otherwise>releaseOdd</xsl:otherwise></xsl:choose></xsl:attribute>
				<td>
					<xsl:call-template name="_printRelease"/>
				</td>
			</tr>
		</xsl:for-each>
	</xsl:template>
	<!--
	Prints the content of a given release, i.e. its version header, its content, and lastly its deliveries.
	The current node must be a 'Release' XML element.
	-->
	<xsl:template name="_printRelease">
		<a>
			<xsl:attribute name="name"><xsl:value-of select="@version"/></xsl:attribute>
		</a>
		<xsl:call-template name="_printReleaseVersion"/>
		<xsl:call-template name="_printReleaseContent"/>
		<xsl:call-template name="_printReleaseDelivery"/>
	</xsl:template>
	<!--
	Writes the detail concerning a given block (composition, dependencies or requirements).
	The current node should be a 'Release' XML element.
	The 'block' parameter is expected and is supposed to indicate the name of the XML element block to be handled.
	-->
	<xsl:template name="_printBlockDetail">
		<xsl:param name="block"/>
		<xsl:variable name="release_current" select="position()"/>
		<xsl:variable name="release_newest">
			<xsl:choose>
				<xsl:when test="*[name() = $block]">
					<xsl:value-of select="count(preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:when test="count(following-sibling::Release[count(*[name() = $block]) > 0]) != 0">
					<xsl:value-of select="count((following-sibling::Release[count(*[name() = $block]) > 0])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="release_oldest">
			<xsl:choose>
				<xsl:when test="count(../Release[position() >= $release_newest and *[name() = $block]/@inherit = 'false']) != 0">
					<xsl:value-of select="count((../Release[position() >= $release_newest and *[name() = $block]/@inherit = 'false'])[1]/preceding-sibling::Release) + 1"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="count(../Release)"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:if test="$release_newest &lt; count(../Release) or ../Release[last()]/*[name() = $block]">
			<br/>
			<table class="{$block}" width="100%">
				<thead>
					<tr>
						<th>
							<i>
								<u>
									<font size="-1">
										<xsl:value-of select="$block"/>
									</font>
								</u>
							</i>
						</th>
					</tr>
				</thead>
				<tbody>
					<xsl:if test="*[name() = $block]/Summary">
						<tr>
							<th colspan="3">
								<xsl:for-each select="*[name() = $block]/Summary">
									<xsl:call-template name="_printContent"/>
								</xsl:for-each>
							</th>
						</tr>
					</xsl:if>
					<xsl:for-each select="../Release">
						<xsl:variable name="release" select="position()"/>
						<xsl:if test="position() >= $release_newest and position() &lt;= $release_oldest">
							<xsl:for-each select="*[name() = $block]/Component">
								<xsl:if test="count(../../../Release[position() >= $release_newest and position() &lt; $release]/*[name() = $block]/Component[@ID = current()/@ID]) = 0">
									<tr>
										<xsl:attribute name="class"><xsl:value-of select="$block"/>Component</xsl:attribute>
										<td width="15%">
											<xsl:choose>
												<xsl:when test="$release = $release_current">
													<xsl:text>new </xsl:text>
												</xsl:when>
												<xsl:otherwise>
													<xsl:text>from&#160;</xsl:text>
													<xsl:call-template name="_writeComponentReleaseA">
														<xsl:with-param name="ID" select="../../../../@ID"/>
														<xsl:with-param name="version" select="../../@version"/>
														<xsl:with-param name="withID" select="false()"/>
													</xsl:call-template>
												</xsl:otherwise>
											</xsl:choose>
										</td>
										<td width="20%">
											<xsl:call-template name="_computeComponentOuterHref">
												<xsl:with-param name="ID" select="@ID"/>
												<xsl:with-param name="version" select="@version"/>
											</xsl:call-template>
										</td>
										<td width="65%">
											<xsl:call-template name="_printContent"/>
										</td>
									</tr>
								</xsl:if>
							</xsl:for-each>
						</xsl:if>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<xsl:template match="xrn:ReleaseNotes/Releases/Release/Features">
		<xsl:if test="Feature">
			<table class="feature" width="100%">
				<tbody>
					<xsl:for-each select="Feature[@ID]">
						<xsl:sort select="@ID"/>
						<xsl:if test="count(preceding-sibling::Feature[@ID = current()/@ID]) = 0">
							<tr class="featureHeader">
								<xsl:if test="@ID">
									<a>
										<xsl:attribute name="name"><xsl:value-of select="../../@version"/>_<xsl:value-of select="@ID"/></xsl:attribute>
									</a>
								</xsl:if>
								<td>
									<xsl:call-template name="_printFeatureIDInheritance">
										<xsl:with-param name="componentID" select="../../../../@ID"/>
										<xsl:with-param name="featureID" select="@parentID"/>
										<xsl:with-param name="childLevel" select="'0'"/>
									</xsl:call-template>
									<xsl:call-template name="_printFeatureIDInheritance">
										<xsl:with-param name="componentID" select="../../../../@ID"/>
										<xsl:with-param name="featureID" select="@ID"/>
										<xsl:with-param name="childLevel" select="'1'"/>
									</xsl:call-template>
								</td>
							</tr>
							<tr>
								<td>
									<xsl:for-each select="../Feature[@ID = current()/@ID]">
										<xsl:call-template name="_printIndividualFeatureContent"/>
									</xsl:for-each>
								</td>
							</tr>
						</xsl:if>
					</xsl:for-each>
					<xsl:for-each select="Feature[not(@ID)]">
						<tr class="featureHeader">
							<td>
								<xsl:text> </xsl:text>
							</td>
						</tr>
						<tr>
							<td>
								<xsl:call-template name="_printIndividualFeatureContent"/>
							</td>
						</tr>
					</xsl:for-each>
				</tbody>
			</table>
		</xsl:if>
	</xsl:template>
	<!--
	Prints the content of a single 'Feature' element, whitout its ID and inheritance description.
	The current node must be the 'Feature' XML element.
	The 'additionalHTMLStuff' parameter enables to add some HTML code after the 'Title'.
	Note that the template assumes that you are currently writting to a 'table/tbody' HTML tag. 
	-->
	<xsl:template name="_printIndividualFeatureContent">
		<xsl:param name="additionalHTMLStuff"/>
		<table cellpadding="0" cellspacing="0" width="100%">
			<tbody>
				<tr>
					<xsl:attribute name="class"><xsl:choose><xsl:when test="(position() mod 2) = 0">featureEven</xsl:when><xsl:otherwise>featureOdd</xsl:otherwise></xsl:choose></xsl:attribute>
					<td>
						<div>
							<xsl:attribute name="class"><xsl:text>featureImportance</xsl:text><xsl:choose><xsl:when test="@importance"><xsl:value-of select="@importance"/></xsl:when><xsl:otherwise>3</xsl:otherwise></xsl:choose></xsl:attribute>
							<xsl:if test="Title">
								<span class="featureSummary">
									<xsl:apply-templates select="Title"/>
								</span>
							</xsl:if>
							<xsl:copy-of select="$additionalHTMLStuff"/>
							<xsl:for-each select="Item">
								<div class="item">
									<xsl:call-template name="_printContent"/>
								</div>
							</xsl:for-each>
							<xsl:call-template name="_printTypeReasonFix"/>
							<xsl:call-template name="_printAskingPersons"/>
							<xsl:call-template name="_printContributors"/>
						</div>
					</td>
				</tr>
			</tbody>
		</table>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printAskingPersons">
		<xsl:if test="count(@askingPersonID | AskingPersons/Actor/@ID) > 0">
			<div align="right">
				<i>
					<font size="-1">
						<xsl:text>asking: </xsl:text>
					</font>
				</i>
				<span class="askingID">
					<xsl:choose>
						<xsl:when test="@askingPersonID">
							<xsl:call-template name="_printActorEMail">
								<xsl:with-param name="ID" select="@askingPersonID"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="AskingPersons/Actor">
								<xsl:call-template name="_printActorEMail">
									<xsl:with-param name="ID" select="@ID"/>
								</xsl:call-template>
								<xsl:if test="position() != last()">
									<xsl:text>, </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printContributors">
		<xsl:if test="count(@contributorID | Contributors/Actor/@ID) > 0">
			<div align="right">
				<i>
					<font size="-1">
						<xsl:text>contributor: </xsl:text>
					</font>
				</i>
				<span class="contributorID">
					<xsl:choose>
						<xsl:when test="@contributorID ">
							<xsl:call-template name="_printActorEMail">
								<xsl:with-param name="ID" select="@contributorID "/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:for-each select="Contributors/Actor">
								<xsl:call-template name="_printActorEMail">
									<xsl:with-param name="ID" select="@ID "/>
								</xsl:call-template>
								<xsl:if test="position() != last()">
									<xsl:text>, </xsl:text>
								</xsl:if>
							</xsl:for-each>
						</xsl:otherwise>
					</xsl:choose>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	Prints the mailto of the provided actor, if its e-mail is being defined via the 'Actors' XML top-child element.
	The 'ID' parameter should be provided an equal to the ID of the actor.
	-->
	<xsl:template name="_printActorEMail">
		<xsl:param name="ID"/>
		<xsl:variable name="displayedID">
			<xsl:choose>
				<xsl:when test="//xrn:ReleaseNotes/Actors/@href and document(//xrn:ReleaseNotes/Actors/@href)/xrna:Actors/Person[@ID = $ID]/@displayName">
					<xsl:for-each select="(document(//xrn:ReleaseNotes/Actors/@href)/xrna:Actors/Person[@ID = $ID])[1]">
						<xsl:value-of select="@displayName"/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$ID"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="//xrn:ReleaseNotes/Actors/@href and document(//xrn:ReleaseNotes/Actors/@href)/xrna:Actors/Person[@ID = $ID]/@eMail">
				<xsl:for-each select="(document(//xrn:ReleaseNotes/Actors/@href)/xrna:Actors/Person[@ID = $ID])[1]">
					<a>
						<xsl:attribute name="href"><xsl:text>mailto:</xsl:text><xsl:value-of select="@eMail"/></xsl:attribute>
						<xsl:value-of select="$displayedID"/>
					</a>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$displayedID"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	The current node must be a 'Features/Feature' XML element.
	-->
	<xsl:template name="_printTypeReasonFix">
		<div align="right">
			<i>
				<font size="-1">
					<xsl:text>detail: </xsl:text>
				</font>
			</i>
			<!--xsl:choose>
				<xsl:when test="$useIcons">
					<img>
						<xsl:attribute name="src"><xsl:value-of select="@type"/><xsl:text>.png</xsl:text></xsl:attribute>
						<xsl:attribute name="alt"><xsl:value-of select="@type"/></xsl:attribute>
						<xsl:attribute name="title"><xsl:value-of select="@type"/></xsl:attribute>
					</img>
				</xsl:when>
				<xsl:otherwise-->
			<span>
				<xsl:attribute name="class"><xsl:value-of select="@type"/>Type</xsl:attribute>
				<xsl:value-of select="@type"/>
				<xsl:text> </xsl:text>
			</span>
			<!--/xsl:otherwise>
			</xsl:choose-->
			<xsl:if test="@fixID">
				<!--xsl:choose>
					<xsl:when test="$useIcons">
						<img src="bug.png" alt="bug-fixing" title="bug-fixing"/>
					</xsl:when>
					<xsl:otherwise-->
				<span class="bug">
					<xsl:text>bug-fixing </xsl:text>
				</span>
				<!--/xsl:otherwise>
				</xsl:choose-->
			</xsl:if>
			<xsl:if test="@reason">
				<span class="reason">
					<xsl:value-of select="@reason"/>
					<xsl:text> </xsl:text>
				</span>
			</xsl:if>
			<xsl:if test="@category">
				<span class="category">
					<xsl:value-of select="@category"/>
					<xsl:text> </xsl:text>
				</span>
			</xsl:if>
		</div>
	</xsl:template>
	<!--
	This templates outputs the ID of a feature. Useless for the moment, but may be usefull when generating a different way a feature link.
	The 'componentID' parameter is expected, and should be equal to the place where the feature is defined.
	The parameter 'featureID' that identifies the feature is expected.
	Warning: this template has been overriden in the multiple HTML page XLST, so do not forget to modify it accordingly if you change this one.
	-->
	<xsl:template name="_printFeatureID">
		<xsl:param name="componentID"/>
		<xsl:param name="featureID"/>
		<xsl:value-of select="$featureID"/>
	</xsl:template>
	<!--
	This templates outputs the ID and the inheritance of an individual feature. The inheritance will limit to the currently selected feature.
	The current node should be a 'Features/Feature' last XML element for which the inheritance is asked for.
	The 'componentID' parameter is expected and shoud be equal to the identifier of the component where the feature is defined.
	The 'featureID' parameter is expected and should be equal to the feature the inheritance computing is being asked for. Note that it may differ from the current node '@ID' attribute.
	The 'childLevel' parameter is expected and should be equal to the number of parents the feature has.
	-->
	<xsl:template name="_printFeatureIDInheritance">
		<xsl:param name="componentID"/>
		<xsl:param name="featureID"/>
		<xsl:param name="childLevel" select="'0'"/>
		<xsl:if test="$featureID">
			<span class="visualNoPrint">
				<span>
					<xsl:attribute name="class"><xsl:choose><xsl:when test="$childLevel &gt; 0">featureID</xsl:when><xsl:otherwise>parentFeatureID</xsl:otherwise></xsl:choose></xsl:attribute>
					<xsl:choose>
						<xsl:when test="$childLevel &gt; 0">
							<xsl:text>&lt;</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>{</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:call-template name="_printFeatureID">
						<xsl:with-param name="componentID" select="$componentID"/>
						<xsl:with-param name="featureID" select="$featureID"/>
					</xsl:call-template>
					<xsl:choose>
						<xsl:when test="$childLevel &gt; 0">
							<xsl:text>&gt;</xsl:text>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>}</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:variable name="release_position" select="count(../../preceding-sibling::Release) + 1"/>
					<xsl:if test="../../../Release[position() &gt; $release_position]/Features/Feature[@ID = $featureID]">
						<xsl:text>&#160;&#160;</xsl:text>
						<font class="version" size="-2">
							<xsl:for-each select="../../../Release[position() &gt; $release_position]/Features/Feature[@ID = $featureID]">
								<xsl:if test="count(preceding-sibling::Feature[@ID = $featureID]) = 0">
									<a>
										<xsl:attribute name="href"><xsl:call-template name="_computePointedFeatureHref"/></xsl:attribute>
										<xsl:text>[</xsl:text>
										<xsl:value-of select="../../@version"/>
										<xsl:text>]</xsl:text>
									</a>
									<xsl:if test="position() != last()">
										<xsl:text>, </xsl:text>
									</xsl:if>
								</xsl:if>
							</xsl:for-each>
						</font>
					</xsl:if>
					<br/>
				</span>
			</span>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the version header part of a release.
	The current node should be a 'Releases/Release' XML element.
	-->
	<xsl:template name="_printReleaseVersion">
		<xsl:variable name="darkness">
			<xsl:call-template name="Dec2Hex">
				<xsl:with-param name="dec" select="128 * (1 + (count(preceding-sibling::Release) div count(../Release)))"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="color">
			<xsl:text>#</xsl:text>
			<xsl:value-of select="$darkness"/>
			<xsl:text>00</xsl:text>
			<xsl:value-of select="$darkness"/>
		</xsl:variable>
		<table width="100%">
			<tbody>
				<tr>
					<td width="80%">
						<div class="versionTitle">
							<span class="version">
								<xsl:value-of select="../../@ID"/>
								<xsl:text>&#160;</xsl:text>
								<xsl:value-of select="@version"/>
							</span>
						</div>
					</td>
					<td width="10%">
						<xsl:attribute name="bgcolor"><xsl:value-of select="$color"/></xsl:attribute>
					</td>
					<td width="10%" bgcolor="#800080"/>
				</tr>
			</tbody>
		</table>
		<xsl:if test="@startDate != ''">
			<div align="right">
				<i>
					<font size="-1">start date: </font>
				</i>
				<span class="date">
					<xsl:value-of select="@startDate"/>
				</span>
			</div>
		</xsl:if>
		<xsl:if test="@buildDate != ''">
			<div align="right">
				<i>
					<font size="-1">build date: </font>
				</i>
				<span class="date">
					<xsl:value-of select="@buildDate"/>
				</span>
			</div>
		</xsl:if>
		<xsl:if test="@deliveryDate != ''">
			<div align="right">
				<i>
					<font size="-1">delivery date: </font>
				</i>
				<span class="date">
					<xsl:value-of select="@deliveryDate"/>
				</span>
			</div>
		</xsl:if>
		<xsl:if test="@builderID != ''">
			<div align="right">
				<i>
					<font size="-1">builder: </font>
				</i>
				<span class="askingID">
					<xsl:call-template name="_printActorEMail">
						<xsl:with-param name="ID" select="@builderID"/>
					</xsl:call-template>
				</span>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	Transforms a decimal number into hexadecimal.
	The 'dec' parameter must be provided.
	Copyright from the web by Magnus (http://groups.google.fr/groups?q=xslt+hexadecimal+number&hl=fr&lr=&selm=9DoJ9.57%24k5.3312%40news.emw.ericsson.se&rnum=1)!
	-->
	<xsl:template name="Dec2Hex">
		<xsl:param name="dec" select="0"/>
		<xsl:variable name="dividend" select="floor($dec div 16)"/>
		<xsl:variable name="rem" select="$dec - ($dividend * 16)"/>
		<xsl:choose>
			<xsl:when test="$dec = 0">0</xsl:when>
			<xsl:when test="$dec = 1">1</xsl:when>
			<xsl:when test="$dec = 2">2</xsl:when>
			<xsl:when test="$dec = 3">3</xsl:when>
			<xsl:when test="$dec = 4">4</xsl:when>
			<xsl:when test="$dec = 5">5</xsl:when>
			<xsl:when test="$dec = 6">6</xsl:when>
			<xsl:when test="$dec = 7">7</xsl:when>
			<xsl:when test="$dec = 8">8</xsl:when>
			<xsl:when test="$dec = 9">9</xsl:when>
			<xsl:when test="$dec = 10">A</xsl:when>
			<xsl:when test="$dec = 11">B</xsl:when>
			<xsl:when test="$dec = 12">C</xsl:when>
			<xsl:when test="$dec = 13">D</xsl:when>
			<xsl:when test="$dec = 14">E</xsl:when>
			<xsl:when test="$dec = 15">F</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="Dec2Hex">
					<xsl:with-param name="dec" select="$dividend"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="$dividend">
			<xsl:call-template name="Dec2Hex">
				<xsl:with-param name="dec" select="$rem"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	<!--
	This templates outputs the content informative part of a release.
	The current node should be a 'Releases/Release' XML element.
	-->
	<xsl:template name="_printReleaseContent">
		<div class="releaseSummary">
			<xsl:for-each select="Summary">
				<xsl:call-template name="_printContent"/>
			</xsl:for-each>
		</div>
		<br/>
		<xsl:apply-templates select="Features"/>
		<xsl:call-template name="_printBlockDetail">
			<xsl:with-param name="block" select="'Composition'"/>
		</xsl:call-template>
		<xsl:call-template name="_printBlockDetail">
			<xsl:with-param name="block" select="'Dependencies'"/>
		</xsl:call-template>
		<xsl:call-template name="_printBlockDetail">
			<xsl:with-param name="block" select="'Requirements'"/>
		</xsl:call-template>
	</xsl:template>
	<!--
	This templates outputs the delivery end-part of a release.
	The current node should be a 'Releases/Release' XML element.
	-->
	<xsl:template name="_printReleaseDelivery">
		<br/>
		<xsl:choose>
			<xsl:when test="Deliveries">
				<table class="delivery" width="100%">
					<thead>
						<tr>
							<th>
								<i>
									<u>
										<font size="-1">Deliveries</font>
									</u>
								</i>
							</th>
						</tr>
					</thead>
					<tbody>
						<xsl:if test="Deliveries/Summary">
							<tr>
								<th colspan="2">
									<xsl:for-each select="Deliveries/Summary">
										<xsl:call-template name="_printContent"/>
									</xsl:for-each>
								</th>
							</tr>
						</xsl:if>
						<xsl:for-each select="Deliveries/Delivery">
							<tr>
								<td width="35%">
									<a>
										<xsl:attribute name="href"><xsl:if test="../../../../Deliveries/@href"><xsl:value-of select="../../../../Deliveries/@href"/><xsl:text>/</xsl:text></xsl:if><xsl:value-of select="@href"/></xsl:attribute>
										<xsl:value-of select="@href"/>
									</a>
								</td>
								<td width="65%">
									<xsl:call-template name="_printContent"/>
								</td>
							</tr>
						</xsl:for-each>
					</tbody>
				</table>
			</xsl:when>
			<xsl:otherwise>
				<table class="delivery" width="100%">
					<thead>
						<tr>
							<th>
								<i>
									<font size="-1">No delivery</font>
								</i>
							</th>
						</tr>
					</thead>
				</table>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Called when some content should be output.
	The current node must be of type 'xrn:contentType'.
	-->
	<xsl:template name="_printContent">
		<xsl:choose>
			<xsl:when test="@contentType = 'html'">
				<xsl:value-of select="." disable-output-escaping="yes"/>
			</xsl:when>
			<xsl:when test="@contentType = 'process'">
				<!--Not possible for the moment, we'll see how to do that for better framework integration...-->
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:when test="not(text())"/>
			<xsl:otherwise>
				<xsl:value-of select="." disable-output-escaping="no"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the bottom banner of the framework.
	The 'copyrightXRNInternal' class CSS selector must be on when calling this template, because setting the selector here generates bad layout...
	-->
	<xsl:template name="_printBottomBanner">
		<xsl:if test="$banner">
			<div align="right">
				<xsl:text>Release notes generated by </xsl:text>
				<strong>
					<i>
						<a href="http://xmlreleasenotes.free.fr" target="_blank">XMLReleaseNotes</a>
					</i>
				</strong>
				<xsl:text> V</xsl:text>
				<xsl:value-of select="$_version"/>
			</div>
		</xsl:if>
	</xsl:template>
	<!--
	Outputs the URL that leads to a precise component release HTML, so that it can be referenced via an HTML anchor.
	The 'ID' parameter is expected and should be equal to the identifier of the concerned component.
	The 'version' parameter is expected and should be equal to the concerned version of the component.
	Warning: this template has been overriden in the multiple HTML page XLST, so do not forget to modify it accordingly if you change this one.
	-->
	<xsl:template name="_computeComponentReleaseURL">
		<xsl:param name="ID"/>
		<xsl:param name="version"/>
		<xsl:text>#</xsl:text>
		<xsl:value-of select="$version"/>
	</xsl:template>
	<!--
	Writes a HTML <a/> tag that points to a component precise release version.
	The 'ID' parameter is expected and should be equal to the identifier of the concerned component.
	The 'version' parameter is expected and should be equal to the concerned version of the component.
	The 'withID' boolean parameter is expected and is supposed to indicate whether the generated hyperlink text should contain the component ID as well.
	-->
	<xsl:template name="_writeComponentReleaseA">
		<xsl:param name="ID"/>
		<xsl:param name="version"/>
		<xsl:param name="withID" select="true()"/>
		<span class="version">
			<a>
				<xsl:attribute name="href"><xsl:call-template name="_computeComponentReleaseURL"><xsl:with-param name="ID" select="$ID"/><xsl:with-param name="version" select="$version"/></xsl:call-template></xsl:attribute>
				<xsl:choose>
					<xsl:when test="$withID">
						<xsl:value-of select="$ID"/>
						<xsl:text>&#160;</xsl:text>
						<xsl:value-of select="$version"/>
					</xsl:when>
					<xsl:otherwise>
						<font size="-2">
							<xsl:value-of select="$version"/>
						</font>
					</xsl:otherwise>
				</xsl:choose>
			</a>
		</span>
	</xsl:template>
	<!--
	Prints the URL of the same feature, but at a different version stage, so that it can be referenced via an HTML anchor.
	The current node must be the 'Feature' XML element on which the reference is being computed.
	Warning: this template has been overriden in the multiple HTML page XLST, so do not forget to modify it accordingly if you change this one.
	-->
	<xsl:template name="_computePointedFeatureHref">
		<xsl:text>#</xsl:text>
		<xsl:value-of select="../../@version"/>
		<xsl:text>_</xsl:text>
		<xsl:value-of select="@ID"/>
	</xsl:template>
	<!--
	Prints the outer URL of the provided component HTML release notes, corresponding to the provided (optional) version.
	The top '/xrn:ReleaseNotes/Components' XML element should be accessible.
	-->
	<xsl:template name="_computeComponentOuterHref">
		<xsl:param name="ID"/>
		<xsl:param name="version"/>
		<xsl:variable name="aText">
			<xsl:value-of select="$ID"/>
		</xsl:variable>
		<xsl:variable name="notAText">
			<xsl:text>&#160;</xsl:text>
			<xsl:value-of select="$version"/>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="/xrn:ReleaseNotes/Components/Component[@ID = $ID]">
				<xsl:choose>
					<xsl:when test="/xrn:ReleaseNotes/Components/Component[@ID = $ID]/@href">
						<a>
							<xsl:attribute name="href"><xsl:value-of select="/xrn:ReleaseNotes/Components/Component[@ID = $ID]/@href"/></xsl:attribute>
							<xsl:value-of select="$aText"/>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$aText"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$aText"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:value-of select="$notAText"/>
	</xsl:template>
</xsl:stylesheet>
